@@ -9,8 +9,10 @@ use {
         consensus::Tower, tower_storage::TowerStorage, validator::ValidatorStartProgress,
     },
     solana_gossip::cluster_info::ClusterInfo,
+    solana_runtime::bank_forks::BankForks,
     solana_sdk::{
         exit::Exit,
+        pubkey::Pubkey,
         signature::{read_keypair_file, Keypair, Signer},
     },
     std::{
@@ -22,6 +24,13 @@ use {
     },
 };
 
+#[derive(Clone)]
+pub struct AdminRpcRequestMetadataPostInit {
+    pub cluster_info: Arc<ClusterInfo>,
+    pub bank_forks: Arc<RwLock<BankForks>>,
+    pub vote_account: Pubkey,
+}
+
 #[derive(Clone)]
 pub struct AdminRpcRequestMetadata {
     pub rpc_addr: Option<SocketAddr>,
@@ -29,11 +38,26 @@ pub struct AdminRpcRequestMetadata {
     pub start_progress: Arc<RwLock<ValidatorStartProgress>>,
     pub validator_exit: Arc<RwLock<Exit>>,
     pub authorized_voter_keypairs: Arc<RwLock<Vec<Arc<Keypair>>>>,
-    pub cluster_info: Arc<RwLock<Option<Arc<ClusterInfo>>>>,
     pub tower_storage: Arc<dyn TowerStorage>,
+    pub post_init: Arc<RwLock<Option<AdminRpcRequestMetadataPostInit>>>,
 }
 impl Metadata for AdminRpcRequestMetadata {}
 
+impl AdminRpcRequestMetadata {
+    fn with_post_init<F>(&self, func: F) -> Result<()>
+    where
+        F: FnOnce(&AdminRpcRequestMetadataPostInit) -> Result<()>,
+    {
+        if let Some(post_init) = self.post_init.read().unwrap().as_ref() {
+            func(post_init)
+        } else {
+            Err(jsonrpc_core::error::Error::invalid_params(
+                "Retry once validator start up is complete",
+            ))
+        }
+    }
+}
+
 #[rpc]
 pub trait AdminRpc {
     type Metadata;
@@ -60,7 +84,12 @@ pub trait AdminRpc {
     fn remove_all_authorized_voters(&self, meta: Self::Metadata) -> Result<()>;
 
     #[rpc(meta, name = "setIdentity")]
-    fn set_identity(&self, meta: Self::Metadata, keypair_file: String) -> Result<()>;
+    fn set_identity(
+        &self,
+        meta: Self::Metadata,
+        keypair_file: String,
+        require_tower: bool,
+    ) -> Result<()>;
 }
 
 pub struct AdminRpcImpl;
@@ -137,7 +166,12 @@ impl AdminRpc for AdminRpcImpl {
         Ok(())
     }
 
-    fn set_identity(&self, meta: Self::Metadata, keypair_file: String) -> Result<()> {
+    fn set_identity(
+        &self,
+        meta: Self::Metadata,
+        keypair_file: String,
+        require_tower: bool,
+    ) -> Result<()> {
         debug!("set_identity request received");
 
         let identity_keypair = read_keypair_file(&keypair_file).map_err(|err| {
@@ -147,25 +181,51 @@ impl AdminRpc for AdminRpcImpl {
             ))
         })?;
 
-        // Ensure a Tower exists for the new identity and exit gracefully.
-        // ReplayStage will be less forgiving if it fails to load the new tower.
-        Tower::restore(meta.tower_storage.as_ref(), &identity_keypair.pubkey()).map_err(|err| {
-            jsonrpc_core::error::Error::invalid_params(format!(
-                "Unable to load tower file for new identity: {}",
-                err
-            ))
-        })?;
+        meta.with_post_init(|post_init| {
+            // Ensure a Tower exists for the new identity and exit gracefully.
+            // ReplayStage will be less forgiving if it fails to load the new tower.
+            if let Err(err) =
+                Tower::restore(meta.tower_storage.as_ref(), &identity_keypair.pubkey()).map_err(
+                    |err| {
+                        jsonrpc_core::error::Error::invalid_params(format!(
+                            "Unable to load tower file for identity {}: {}",
+                            identity_keypair.pubkey(),
+                            err
+                        ))
+                    },
+                )
+            {
+                if require_tower {
+                    return Err(err);
+                }
+
+                let root_bank = post_init.bank_forks.read().unwrap().root_bank();
+                let mut tower = Tower::new(
+                    &identity_keypair.pubkey(),
+                    &post_init.vote_account,
+                    root_bank.slot(),
+                    &root_bank,
+                );
+                // Forge a single vote to pacify `Tower::adjust_lockouts_after_replay` when its called
+                // by replay_stage
+                tower.record_bank_vote(&root_bank, &post_init.vote_account);
+                tower
+                    .save(meta.tower_storage.as_ref(), &identity_keypair)
+                    .map_err(|err| {
+                        jsonrpc_core::error::Error::invalid_params(format!(
+                            "Unable to create default tower file for ephemeral identity: {}",
+                            err
+                        ))
+                    })?;
+            }
 
-        if let Some(cluster_info) = meta.cluster_info.read().unwrap().as_ref() {
             solana_metrics::set_host_id(identity_keypair.pubkey().to_string());
-            cluster_info.set_keypair(Arc::new(identity_keypair));
-            warn!("Identity set to {}", cluster_info.id());
+            post_init
+                .cluster_info
+                .set_keypair(Arc::new(identity_keypair));
+            warn!("Identity set to {}", post_init.cluster_info.id());
             Ok(())
-        } else {
-            Err(jsonrpc_core::error::Error::invalid_params(
-                "Retry once validator start up is complete",
-            ))
-        }
+        })
     }
 }
 
